@@ -3,8 +3,12 @@
  */
 
 #include <fstream>
-#include <ginac/ginac.h>
 
+#ifdef IN_GINAC
+#include "ginac.h"
+#else
+#include <ginac/ginac.h>
+#endif
 using namespace std;
 using namespace GiNaC;
 
