@@ -82,7 +82,6 @@
 #include <sys/types.h>
 #include <unistd.h>
 #endif
-
 #include <stdexcept>
 
 #include "ginsh.h"
@@ -158,7 +157,7 @@ static void insert_fcn_help(const char *name, const char *str);
 static void print_help(const string &topic);
 static void print_help_topics(void);
 
-#line 162 "ginsh_parser.cpp"
+#line 161 "ginsh_parser.cpp"
 
 # ifndef YY_CAST
 #  ifdef __cplusplus
@@ -632,13 +631,13 @@ static const yytype_int8 yytranslate[] =
 /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_int16 yyrline[] =
 {
-       0,   146,   146,   147,   150,   151,   160,   168,   176,   190,
-     198,   206,   207,   208,   209,   210,   211,   212,   213,   214,
-     227,   228,   229,   230,   235,   236,   237,   237,   238,   239,
-     242,   243,   250,   251,   252,   253,   254,   255,   256,   264,
-     265,   266,   267,   268,   269,   270,   271,   272,   273,   274,
-     275,   276,   277,   278,   279,   280,   281,   282,   285,   286,
-     289,   290,   293,   294,   297,   298,   301,   302
+       0,   145,   145,   146,   149,   150,   159,   167,   175,   189,
+     197,   205,   206,   207,   208,   209,   210,   211,   212,   213,
+     226,   227,   228,   229,   234,   235,   236,   236,   237,   238,
+     241,   242,   249,   250,   251,   252,   253,   254,   255,   263,
+     264,   272,   273,   274,   275,   276,   277,   278,   279,   280,
+     281,   282,   283,   284,   285,   286,   287,   288,   291,   292,
+     295,   296,   299,   300,   303,   304,   307,   308
 };
 #endif
 
@@ -1310,7 +1309,7 @@ yyreduce:
   switch (yyn)
     {
   case 5: /* line: exp ';'  */
-#line 151 "ginsh_parser.ypp"
+#line 150 "ginsh_parser.ypp"
                   {
 		try {
 			cout << yyvsp[-1] << endl;
@@ -1320,11 +1319,11 @@ yyreduce:
 			YYERROR;
 		}
 	}
-#line 1324 "ginsh_parser.cpp"
+#line 1323 "ginsh_parser.cpp"
     break;
 
   case 6: /* line: exp ':'  */
-#line 160 "ginsh_parser.ypp"
+#line 159 "ginsh_parser.ypp"
                   {
 		try {
 			push(yyvsp[-1]);
@@ -1333,11 +1332,11 @@ yyreduce:
 			YYERROR;
 		}
 	}
-#line 1337 "ginsh_parser.cpp"
+#line 1336 "ginsh_parser.cpp"
     break;
 
   case 7: /* line: T_PRINT '(' exp ')' ';'  */
-#line 168 "ginsh_parser.ypp"
+#line 167 "ginsh_parser.ypp"
                                   {
 		try {
 			yyvsp[-2].print(print_tree(std::cout));
@@ -1346,11 +1345,11 @@ yyreduce:
 			YYERROR;
 		}
 	}
-#line 1350 "ginsh_parser.cpp"
+#line 1349 "ginsh_parser.cpp"
     break;
 
   case 8: /* line: T_IPRINT '(' exp ')' ';'  */
-#line 176 "ginsh_parser.ypp"
+#line 175 "ginsh_parser.ypp"
                                    {
 		try {
 			ex e = yyvsp[-2];
@@ -1365,11 +1364,11 @@ yyreduce:
 			YYERROR;
 		}
 	}
-#line 1369 "ginsh_parser.cpp"
+#line 1368 "ginsh_parser.cpp"
     break;
 
   case 9: /* line: T_PRINTLATEX '(' exp ')' ';'  */
-#line 190 "ginsh_parser.ypp"
+#line 189 "ginsh_parser.ypp"
                                        {
 		try {
 			yyvsp[-2].print(print_latex(std::cout)); cout << endl;
@@ -1378,11 +1377,11 @@ yyreduce:
 			YYERROR;
 		}
 	}
-#line 1382 "ginsh_parser.cpp"
+#line 1381 "ginsh_parser.cpp"
     break;
 
   case 10: /* line: T_PRINTCSRC '(' exp ')' ';'  */
-#line 198 "ginsh_parser.ypp"
+#line 197 "ginsh_parser.ypp"
                                       {
 		try {
 			yyvsp[-2].print(print_csrc_double(std::cout)); cout << endl;
@@ -1391,59 +1390,59 @@ yyreduce:
 			YYERROR;
 		}
 	}
-#line 1395 "ginsh_parser.cpp"
+#line 1394 "ginsh_parser.cpp"
     break;
 
   case 11: /* line: '?' T_SYMBOL  */
-#line 206 "ginsh_parser.ypp"
+#line 205 "ginsh_parser.ypp"
                                 {print_help(ex_to<symbol>(yyvsp[0]).get_name());}
-#line 1401 "ginsh_parser.cpp"
+#line 1400 "ginsh_parser.cpp"
     break;
 
   case 12: /* line: '?' T_TIME  */
-#line 207 "ginsh_parser.ypp"
+#line 206 "ginsh_parser.ypp"
                                 {print_help("time");}
-#line 1407 "ginsh_parser.cpp"
+#line 1406 "ginsh_parser.cpp"
     break;
 
   case 13: /* line: '?' T_PRINT  */
-#line 208 "ginsh_parser.ypp"
+#line 207 "ginsh_parser.ypp"
                                 {print_help("print");}
-#line 1413 "ginsh_parser.cpp"
+#line 1412 "ginsh_parser.cpp"
     break;
 
   case 14: /* line: '?' T_IPRINT  */
-#line 209 "ginsh_parser.ypp"
+#line 208 "ginsh_parser.ypp"
                                 {print_help("iprint");}
-#line 1419 "ginsh_parser.cpp"
+#line 1418 "ginsh_parser.cpp"
     break;
 
   case 15: /* line: '?' T_PRINTLATEX  */
-#line 210 "ginsh_parser.ypp"
+#line 209 "ginsh_parser.ypp"
                                 {print_help("print_latex");}
-#line 1425 "ginsh_parser.cpp"
+#line 1424 "ginsh_parser.cpp"
     break;
 
   case 16: /* line: '?' T_PRINTCSRC  */
-#line 211 "ginsh_parser.ypp"
+#line 210 "ginsh_parser.ypp"
                                 {print_help("print_csrc");}
-#line 1431 "ginsh_parser.cpp"
+#line 1430 "ginsh_parser.cpp"
     break;
 
   case 17: /* line: '?' '?'  */
-#line 212 "ginsh_parser.ypp"
+#line 211 "ginsh_parser.ypp"
                                 {print_help_topics();}
-#line 1437 "ginsh_parser.cpp"
+#line 1436 "ginsh_parser.cpp"
     break;
 
   case 18: /* line: T_QUIT  */
-#line 213 "ginsh_parser.ypp"
+#line 212 "ginsh_parser.ypp"
                                 {YYACCEPT;}
-#line 1443 "ginsh_parser.cpp"
+#line 1442 "ginsh_parser.cpp"
     break;
 
   case 19: /* line: T_WARRANTY  */
-#line 214 "ginsh_parser.ypp"
+#line 213 "ginsh_parser.ypp"
                      {
 		cout << "This program is free software; you can redistribute it and/or modify it under\n";
 		cout << "the terms of the GNU General Public License as published by the Free Software\n";
@@ -1457,81 +1456,81 @@ yyreduce:
 		cout << "this program. If not, write to the Free Software Foundation,\n";
 		cout << "51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.\n";
 	}
-#line 1461 "ginsh_parser.cpp"
+#line 1460 "ginsh_parser.cpp"
     break;
 
   case 20: /* line: T_XYZZY  */
-#line 227 "ginsh_parser.ypp"
+#line 226 "ginsh_parser.ypp"
                                 {cout << "Nothing happens.\n";}
-#line 1467 "ginsh_parser.cpp"
+#line 1466 "ginsh_parser.cpp"
     break;
 
   case 21: /* line: T_INVENTORY  */
-#line 228 "ginsh_parser.ypp"
+#line 227 "ginsh_parser.ypp"
                                 {cout << "You're not carrying anything.\n";}
-#line 1473 "ginsh_parser.cpp"
+#line 1472 "ginsh_parser.cpp"
     break;
 
   case 22: /* line: T_LOOK  */
-#line 229 "ginsh_parser.ypp"
+#line 228 "ginsh_parser.ypp"
                                 {cout << "You're in a twisty little maze of passages, all alike.\n";}
-#line 1479 "ginsh_parser.cpp"
+#line 1478 "ginsh_parser.cpp"
     break;
 
   case 23: /* line: T_SCORE  */
-#line 230 "ginsh_parser.ypp"
+#line 229 "ginsh_parser.ypp"
                   {
 		cout << "If you were to quit now, you would score ";
 		cout << (syms.size() > 350 ? 350 : syms.size());
 		cout << " out of a possible 350.\n";
 	}
-#line 1489 "ginsh_parser.cpp"
+#line 1488 "ginsh_parser.cpp"
     break;
 
   case 24: /* line: T_REAL_SYMBOLS  */
-#line 235 "ginsh_parser.ypp"
+#line 234 "ginsh_parser.ypp"
                          { symboltype = domain::real; }
-#line 1495 "ginsh_parser.cpp"
+#line 1494 "ginsh_parser.cpp"
     break;
 
   case 25: /* line: T_COMPLEX_SYMBOLS  */
-#line 236 "ginsh_parser.ypp"
+#line 235 "ginsh_parser.ypp"
                             { symboltype = domain::complex; }
-#line 1501 "ginsh_parser.cpp"
+#line 1500 "ginsh_parser.cpp"
     break;
 
   case 26: /* $@1: %empty  */
-#line 237 "ginsh_parser.ypp"
+#line 236 "ginsh_parser.ypp"
                  { START_TIMER }
-#line 1507 "ginsh_parser.cpp"
+#line 1506 "ginsh_parser.cpp"
     break;
 
   case 27: /* line: T_TIME $@1 '(' exp ')'  */
-#line 237 "ginsh_parser.ypp"
+#line 236 "ginsh_parser.ypp"
                                              { STOP_TIMER PRINT_TIME_USED }
-#line 1513 "ginsh_parser.cpp"
+#line 1512 "ginsh_parser.cpp"
     break;
 
   case 28: /* line: error ';'  */
-#line 238 "ginsh_parser.ypp"
+#line 237 "ginsh_parser.ypp"
                                 {yyclearin; yyerrok;}
-#line 1519 "ginsh_parser.cpp"
+#line 1518 "ginsh_parser.cpp"
     break;
 
   case 29: /* line: error ':'  */
-#line 239 "ginsh_parser.ypp"
+#line 238 "ginsh_parser.ypp"
                                 {yyclearin; yyerrok;}
-#line 1525 "ginsh_parser.cpp"
+#line 1524 "ginsh_parser.cpp"
     break;
 
   case 30: /* exp: T_NUMBER  */
-#line 242 "ginsh_parser.ypp"
+#line 241 "ginsh_parser.ypp"
                                 {yyval = yyvsp[0];}
-#line 1531 "ginsh_parser.cpp"
+#line 1530 "ginsh_parser.cpp"
     break;
 
   case 31: /* exp: T_SYMBOL  */
-#line 243 "ginsh_parser.ypp"
+#line 242 "ginsh_parser.ypp"
                                 {
 		auto i = assigned_symbol_table.find(yyvsp[0]);
 		if (i == assigned_symbol_table.end())
@@ -1539,47 +1538,47 @@ yyreduce:
 		else
 			yyval = i->second;
 	}
-#line 1543 "ginsh_parser.cpp"
+#line 1542 "ginsh_parser.cpp"
     break;
 
   case 32: /* exp: '\'' T_SYMBOL '\''  */
-#line 250 "ginsh_parser.ypp"
+#line 249 "ginsh_parser.ypp"
                                 {yyval = yyvsp[-1];}
-#line 1549 "ginsh_parser.cpp"
+#line 1548 "ginsh_parser.cpp"
     break;
 
   case 33: /* exp: T_LITERAL  */
-#line 251 "ginsh_parser.ypp"
+#line 250 "ginsh_parser.ypp"
                                 {yyval = yyvsp[0];}
-#line 1555 "ginsh_parser.cpp"
+#line 1554 "ginsh_parser.cpp"
     break;
 
   case 34: /* exp: T_DIGITS  */
-#line 252 "ginsh_parser.ypp"
+#line 251 "ginsh_parser.ypp"
                                 {yyval = yyvsp[0];}
-#line 1561 "ginsh_parser.cpp"
+#line 1560 "ginsh_parser.cpp"
     break;
 
   case 35: /* exp: T_QUOTE  */
-#line 253 "ginsh_parser.ypp"
+#line 252 "ginsh_parser.ypp"
                                 {yyval = exstack[0];}
-#line 1567 "ginsh_parser.cpp"
+#line 1566 "ginsh_parser.cpp"
     break;
 
   case 36: /* exp: T_QUOTE2  */
-#line 254 "ginsh_parser.ypp"
+#line 253 "ginsh_parser.ypp"
                                 {yyval = exstack[1];}
-#line 1573 "ginsh_parser.cpp"
+#line 1572 "ginsh_parser.cpp"
     break;
 
   case 37: /* exp: T_QUOTE3  */
-#line 255 "ginsh_parser.ypp"
+#line 254 "ginsh_parser.ypp"
                                 {yyval = exstack[2];}
-#line 1579 "ginsh_parser.cpp"
+#line 1578 "ginsh_parser.cpp"
     break;
 
   case 38: /* exp: T_SYMBOL '(' exprseq ')'  */
-#line 256 "ginsh_parser.ypp"
+#line 255 "ginsh_parser.ypp"
                                    {
 		auto i = find_function(yyvsp[-3], yyvsp[-1].nops());
 		if (i->second.is_ginac) {
@@ -1588,185 +1587,192 @@ yyreduce:
 			yyval = (i->second.p)(ex_to<exprseq>(yyvsp[-1]));
 		}
 	}
-#line 1592 "ginsh_parser.cpp"
+#line 1591 "ginsh_parser.cpp"
     break;
 
   case 39: /* exp: T_DIGITS '=' T_NUMBER  */
-#line 264 "ginsh_parser.ypp"
+#line 263 "ginsh_parser.ypp"
                                 {yyval = yyvsp[0]; Digits = ex_to<numeric>(yyvsp[0]).to_int();}
-#line 1598 "ginsh_parser.cpp"
+#line 1597 "ginsh_parser.cpp"
     break;
 
   case 40: /* exp: T_SYMBOL '=' exp  */
-#line 265 "ginsh_parser.ypp"
-                                {yyval = yyvsp[0]; assigned_symbol_table[yyvsp[-2]] = yyvsp[0]; }
-#line 1604 "ginsh_parser.cpp"
-    break;
-
-  case 41: /* exp: exp T_EQUAL exp  */
-#line 266 "ginsh_parser.ypp"
-                                {yyval = yyvsp[-2] == yyvsp[0];}
+#line 264 "ginsh_parser.ypp"
+                                {
+		yyval = yyvsp[0];
+		const exmap m{{yyvsp[-2], yyvsp[0]}};
+		for (auto & s : assigned_symbol_table) {
+			s.second = s.second.subs(m);
+		}
+		assigned_symbol_table[yyvsp[-2]] = yyvsp[0];
+	}
 #line 1610 "ginsh_parser.cpp"
     break;
 
-  case 42: /* exp: exp T_NOTEQ exp  */
-#line 267 "ginsh_parser.ypp"
-                                {yyval = yyvsp[-2] != yyvsp[0];}
+  case 41: /* exp: exp T_EQUAL exp  */
+#line 272 "ginsh_parser.ypp"
+                                {yyval = yyvsp[-2] == yyvsp[0];}
 #line 1616 "ginsh_parser.cpp"
     break;
 
-  case 43: /* exp: exp '<' exp  */
-#line 268 "ginsh_parser.ypp"
-                                {yyval = yyvsp[-2] < yyvsp[0];}
+  case 42: /* exp: exp T_NOTEQ exp  */
+#line 273 "ginsh_parser.ypp"
+                                {yyval = yyvsp[-2] != yyvsp[0];}
 #line 1622 "ginsh_parser.cpp"
     break;
 
-  case 44: /* exp: exp T_LESSEQ exp  */
-#line 269 "ginsh_parser.ypp"
-                                {yyval = yyvsp[-2] <= yyvsp[0];}
+  case 43: /* exp: exp '<' exp  */
+#line 274 "ginsh_parser.ypp"
+                                {yyval = yyvsp[-2] < yyvsp[0];}
 #line 1628 "ginsh_parser.cpp"
     break;
 
-  case 45: /* exp: exp '>' exp  */
-#line 270 "ginsh_parser.ypp"
-                                {yyval = yyvsp[-2] > yyvsp[0];}
+  case 44: /* exp: exp T_LESSEQ exp  */
+#line 275 "ginsh_parser.ypp"
+                                {yyval = yyvsp[-2] <= yyvsp[0];}
 #line 1634 "ginsh_parser.cpp"
     break;
 
-  case 46: /* exp: exp T_GREATEREQ exp  */
-#line 271 "ginsh_parser.ypp"
-                                {yyval = yyvsp[-2] >= yyvsp[0];}
+  case 45: /* exp: exp '>' exp  */
+#line 276 "ginsh_parser.ypp"
+                                {yyval = yyvsp[-2] > yyvsp[0];}
 #line 1640 "ginsh_parser.cpp"
     break;
 
-  case 47: /* exp: exp '+' exp  */
-#line 272 "ginsh_parser.ypp"
-                                {yyval = yyvsp[-2] + yyvsp[0];}
+  case 46: /* exp: exp T_GREATEREQ exp  */
+#line 277 "ginsh_parser.ypp"
+                                {yyval = yyvsp[-2] >= yyvsp[0];}
 #line 1646 "ginsh_parser.cpp"
     break;
 
-  case 48: /* exp: exp '-' exp  */
-#line 273 "ginsh_parser.ypp"
-                                {yyval = yyvsp[-2] - yyvsp[0];}
+  case 47: /* exp: exp '+' exp  */
+#line 278 "ginsh_parser.ypp"
+                                {yyval = yyvsp[-2] + yyvsp[0];}
 #line 1652 "ginsh_parser.cpp"
     break;
 
-  case 49: /* exp: exp '*' exp  */
-#line 274 "ginsh_parser.ypp"
-                                {yyval = yyvsp[-2] * yyvsp[0];}
+  case 48: /* exp: exp '-' exp  */
+#line 279 "ginsh_parser.ypp"
+                                {yyval = yyvsp[-2] - yyvsp[0];}
 #line 1658 "ginsh_parser.cpp"
     break;
 
-  case 50: /* exp: exp '/' exp  */
-#line 275 "ginsh_parser.ypp"
-                                {yyval = yyvsp[-2] / yyvsp[0];}
+  case 49: /* exp: exp '*' exp  */
+#line 280 "ginsh_parser.ypp"
+                                {yyval = yyvsp[-2] * yyvsp[0];}
 #line 1664 "ginsh_parser.cpp"
     break;
 
-  case 51: /* exp: '-' exp  */
-#line 276 "ginsh_parser.ypp"
-                                {yyval = -yyvsp[0];}
+  case 50: /* exp: exp '/' exp  */
+#line 281 "ginsh_parser.ypp"
+                                {yyval = yyvsp[-2] / yyvsp[0];}
 #line 1670 "ginsh_parser.cpp"
     break;
 
-  case 52: /* exp: '+' exp  */
-#line 277 "ginsh_parser.ypp"
-                                {yyval = yyvsp[0];}
+  case 51: /* exp: '-' exp  */
+#line 282 "ginsh_parser.ypp"
+                                {yyval = -yyvsp[0];}
 #line 1676 "ginsh_parser.cpp"
     break;
 
-  case 53: /* exp: exp '^' exp  */
-#line 278 "ginsh_parser.ypp"
-                                {yyval = power(yyvsp[-2], yyvsp[0]);}
+  case 52: /* exp: '+' exp  */
+#line 283 "ginsh_parser.ypp"
+                                {yyval = yyvsp[0];}
 #line 1682 "ginsh_parser.cpp"
     break;
 
-  case 54: /* exp: exp '!'  */
-#line 279 "ginsh_parser.ypp"
-                                {yyval = factorial(yyvsp[-1]);}
+  case 53: /* exp: exp '^' exp  */
+#line 284 "ginsh_parser.ypp"
+                                {yyval = power(yyvsp[-2], yyvsp[0]);}
 #line 1688 "ginsh_parser.cpp"
     break;
 
-  case 55: /* exp: '(' exp ')'  */
-#line 280 "ginsh_parser.ypp"
-                                {yyval = yyvsp[-1];}
+  case 54: /* exp: exp '!'  */
+#line 285 "ginsh_parser.ypp"
+                                {yyval = factorial(yyvsp[-1]);}
 #line 1694 "ginsh_parser.cpp"
     break;
 
-  case 56: /* exp: '{' list_or_empty '}'  */
-#line 281 "ginsh_parser.ypp"
+  case 55: /* exp: '(' exp ')'  */
+#line 286 "ginsh_parser.ypp"
                                 {yyval = yyvsp[-1];}
 #line 1700 "ginsh_parser.cpp"
     break;
 
-  case 57: /* exp: '[' matrix ']'  */
-#line 282 "ginsh_parser.ypp"
-                                {yyval = lst_to_matrix(ex_to<lst>(yyvsp[-1]));}
+  case 56: /* exp: '{' list_or_empty '}'  */
+#line 287 "ginsh_parser.ypp"
+                                {yyval = yyvsp[-1];}
 #line 1706 "ginsh_parser.cpp"
     break;
 
-  case 58: /* exprseq: exp  */
-#line 285 "ginsh_parser.ypp"
-                                {yyval = exprseq{yyvsp[0]};}
+  case 57: /* exp: '[' matrix ']'  */
+#line 288 "ginsh_parser.ypp"
+                                {yyval = lst_to_matrix(ex_to<lst>(yyvsp[-1]));}
 #line 1712 "ginsh_parser.cpp"
     break;
 
-  case 59: /* exprseq: exprseq ',' exp  */
-#line 286 "ginsh_parser.ypp"
-                                {exprseq es(ex_to<exprseq>(yyvsp[-2])); yyval = es.append(yyvsp[0]);}
+  case 58: /* exprseq: exp  */
+#line 291 "ginsh_parser.ypp"
+                                {yyval = exprseq{yyvsp[0]};}
 #line 1718 "ginsh_parser.cpp"
     break;
 
-  case 60: /* list_or_empty: %empty  */
-#line 289 "ginsh_parser.ypp"
-                                {yyval = *new lst;}
+  case 59: /* exprseq: exprseq ',' exp  */
+#line 292 "ginsh_parser.ypp"
+                                {exprseq es(ex_to<exprseq>(yyvsp[-2])); yyval = es.append(yyvsp[0]);}
 #line 1724 "ginsh_parser.cpp"
     break;
 
-  case 61: /* list_or_empty: list  */
-#line 290 "ginsh_parser.ypp"
-                                {yyval = yyvsp[0];}
+  case 60: /* list_or_empty: %empty  */
+#line 295 "ginsh_parser.ypp"
+                                {yyval = *new lst;}
 #line 1730 "ginsh_parser.cpp"
     break;
 
-  case 62: /* list: exp  */
-#line 293 "ginsh_parser.ypp"
-                                {yyval = lst{yyvsp[0]};}
+  case 61: /* list_or_empty: list  */
+#line 296 "ginsh_parser.ypp"
+                                {yyval = yyvsp[0];}
 #line 1736 "ginsh_parser.cpp"
     break;
 
-  case 63: /* list: list ',' exp  */
-#line 294 "ginsh_parser.ypp"
-                                {lst l(ex_to<lst>(yyvsp[-2])); yyval = l.append(yyvsp[0]);}
+  case 62: /* list: exp  */
+#line 299 "ginsh_parser.ypp"
+                                {yyval = lst{yyvsp[0]};}
 #line 1742 "ginsh_parser.cpp"
     break;
 
-  case 64: /* matrix: '[' row ']'  */
-#line 297 "ginsh_parser.ypp"
-                                {yyval = lst{yyvsp[-1]};}
+  case 63: /* list: list ',' exp  */
+#line 300 "ginsh_parser.ypp"
+                                {lst l(ex_to<lst>(yyvsp[-2])); yyval = l.append(yyvsp[0]);}
 #line 1748 "ginsh_parser.cpp"
     break;
 
-  case 65: /* matrix: matrix ',' '[' row ']'  */
-#line 298 "ginsh_parser.ypp"
-                                 {lst l(ex_to<lst>(yyvsp[-4])); yyval = l.append(yyvsp[-1]);}
+  case 64: /* matrix: '[' row ']'  */
+#line 303 "ginsh_parser.ypp"
+                                {yyval = lst{yyvsp[-1]};}
 #line 1754 "ginsh_parser.cpp"
     break;
 
-  case 66: /* row: exp  */
-#line 301 "ginsh_parser.ypp"
-                                {yyval = lst{yyvsp[0]};}
+  case 65: /* matrix: matrix ',' '[' row ']'  */
+#line 304 "ginsh_parser.ypp"
+                                 {lst l(ex_to<lst>(yyvsp[-4])); yyval = l.append(yyvsp[-1]);}
 #line 1760 "ginsh_parser.cpp"
     break;
 
-  case 67: /* row: row ',' exp  */
-#line 302 "ginsh_parser.ypp"
-                                {lst l(ex_to<lst>(yyvsp[-2])); yyval = l.append(yyvsp[0]);}
+  case 66: /* row: exp  */
+#line 307 "ginsh_parser.ypp"
+                                {yyval = lst{yyvsp[0]};}
 #line 1766 "ginsh_parser.cpp"
     break;
 
+  case 67: /* row: row ',' exp  */
+#line 308 "ginsh_parser.ypp"
+                                {lst l(ex_to<lst>(yyvsp[-2])); yyval = l.append(yyvsp[0]);}
+#line 1772 "ginsh_parser.cpp"
+    break;
 
-#line 1770 "ginsh_parser.cpp"
+
+#line 1776 "ginsh_parser.cpp"
 
       default: break;
     }
@@ -1959,7 +1965,7 @@ yyreturnlab:
   return yyresult;
 }
 
-#line 310 "ginsh_parser.ypp"
+#line 316 "ginsh_parser.ypp"
 
 // Error print routine
 int yyerror(const char *s)
@@ -2666,7 +2672,7 @@ static void ginsh_readline_init(char* name)
 void greeting(void)
 {
     cout << "ginsh - GiNaC Interactive Shell (GiNaC V" << GINACLIB_VERSION << ")" << endl;
-    cout << "  __,  _______  Copyright (C) 1999-2023 Johannes Gutenberg University Mainz,\n"
+    cout << "  __,  _______  Copyright (C) 1999-2025 Johannes Gutenberg University Mainz,\n"
          << " (__) *       | Germany.  This is free software with ABSOLUTELY NO WARRANTY.\n"
          << "  ._) i N a C | You are welcome to redistribute it under certain conditions.\n"
          << "<-------------' For details type `warranty;'.\n" << endl;
